## Project
This project contains a nova backend that can be used to train models or generate explanations for the models on a remote server.
The server api can be used either from the UI itself or as a standalone tool to just interact with an existing nova database.
You can find the full documentation of the project [here](https://hcmlab.github.io/nova-server/docbuild/).
